==> zio-aws-mgn_2.13-5.17.128.1-sources.jar: zio/aws/mgn/model/ReplicationConfigurationDefaultLargeStagingDiskType.scala <==
package zio.aws.mgn.model
import scala.jdk.CollectionConverters._
sealed trait ReplicationConfigurationDefaultLargeStagingDiskType {
  def unwrap: software.amazon.awssdk.services.mgn.model.ReplicationConfigurationDefaultLargeStagingDiskType
}
object ReplicationConfigurationDefaultLargeStagingDiskType {
  def wrap(
      value: software.amazon.awssdk.services.mgn.model.ReplicationConfigurationDefaultLargeStagingDiskType
  ): zio.aws.mgn.model.ReplicationConfigurationDefaultLargeStagingDiskType =
    value match {
      case software.amazon.awssdk.services.mgn.model.ReplicationConfigurationDefaultLargeStagingDiskType.UNKNOWN_TO_SDK_VERSION =>
        val r = unknownToSdkVersion
        r
      case software.amazon.awssdk.services.mgn.model.ReplicationConfigurationDefaultLargeStagingDiskType.GP2 =>
        val r = GP2
        r
      case software.amazon.awssdk.services.mgn.model.ReplicationConfigurationDefaultLargeStagingDiskType.ST1 =>
        val r = ST1
        r
    }
  case object unknownToSdkVersion
      extends zio.aws.mgn.model.ReplicationConfigurationDefaultLargeStagingDiskType {
    override def unwrap
        : software.amazon.awssdk.services.mgn.model.ReplicationConfigurationDefaultLargeStagingDiskType =
      software.amazon.awssdk.services.mgn.model.ReplicationConfigurationDefaultLargeStagingDiskType.UNKNOWN_TO_SDK_VERSION
  }
  case object GP2
      extends zio.aws.mgn.model.ReplicationConfigurationDefaultLargeStagingDiskType {
    override def unwrap
        : software.amazon.awssdk.services.mgn.model.ReplicationConfigurationDefaultLargeStagingDiskType =
      software.amazon.awssdk.services.mgn.model.ReplicationConfigurationDefaultLargeStagingDiskType.GP2
  }
  case object ST1
      extends zio.aws.mgn.model.ReplicationConfigurationDefaultLargeStagingDiskType {
    override def unwrap
        : software.amazon.awssdk.services.mgn.model.ReplicationConfigurationDefaultLargeStagingDiskType =
      software.amazon.awssdk.services.mgn.model.ReplicationConfigurationDefaultLargeStagingDiskType.ST1
  }
}

==> zio-aws-mgn_2.13-5.20.17.1-sources.jar: zio/aws/mgn/model/ReplicationConfigurationDefaultLargeStagingDiskType.scala <==
package zio.aws.mgn.model
import scala.jdk.CollectionConverters._
sealed trait ReplicationConfigurationDefaultLargeStagingDiskType {
  def unwrap: software.amazon.awssdk.services.mgn.model.ReplicationConfigurationDefaultLargeStagingDiskType
}
object ReplicationConfigurationDefaultLargeStagingDiskType {
  def wrap(
      value: software.amazon.awssdk.services.mgn.model.ReplicationConfigurationDefaultLargeStagingDiskType
  ): zio.aws.mgn.model.ReplicationConfigurationDefaultLargeStagingDiskType =
    value match {
      case software.amazon.awssdk.services.mgn.model.ReplicationConfigurationDefaultLargeStagingDiskType.UNKNOWN_TO_SDK_VERSION =>
        val r = unknownToSdkVersion
        r
      case software.amazon.awssdk.services.mgn.model.ReplicationConfigurationDefaultLargeStagingDiskType.GP2 =>
        val r = GP2
        r
      case software.amazon.awssdk.services.mgn.model.ReplicationConfigurationDefaultLargeStagingDiskType.ST1 =>
        val r = ST1
        r
      case software.amazon.awssdk.services.mgn.model.ReplicationConfigurationDefaultLargeStagingDiskType.GP3 =>
        val r = GP3
        r
    }
  case object unknownToSdkVersion
      extends zio.aws.mgn.model.ReplicationConfigurationDefaultLargeStagingDiskType {
    override def unwrap
        : software.amazon.awssdk.services.mgn.model.ReplicationConfigurationDefaultLargeStagingDiskType =
      software.amazon.awssdk.services.mgn.model.ReplicationConfigurationDefaultLargeStagingDiskType.UNKNOWN_TO_SDK_VERSION
  }
  case object GP2
      extends zio.aws.mgn.model.ReplicationConfigurationDefaultLargeStagingDiskType {
    override def unwrap
        : software.amazon.awssdk.services.mgn.model.ReplicationConfigurationDefaultLargeStagingDiskType =
      software.amazon.awssdk.services.mgn.model.ReplicationConfigurationDefaultLargeStagingDiskType.GP2
  }
  case object ST1
      extends zio.aws.mgn.model.ReplicationConfigurationDefaultLargeStagingDiskType {
    override def unwrap
        : software.amazon.awssdk.services.mgn.model.ReplicationConfigurationDefaultLargeStagingDiskType =
      software.amazon.awssdk.services.mgn.model.ReplicationConfigurationDefaultLargeStagingDiskType.ST1
  }
  case object GP3
      extends zio.aws.mgn.model.ReplicationConfigurationDefaultLargeStagingDiskType {
    override def unwrap
        : software.amazon.awssdk.services.mgn.model.ReplicationConfigurationDefaultLargeStagingDiskType =
      software.amazon.awssdk.services.mgn.model.ReplicationConfigurationDefaultLargeStagingDiskType.GP3
  }
}
